@@ -156,8 +156,7 @@ func (cfg *PackerConfig) EvalContext(ctx BlockContext, variables map[string]cty.
 func (c *PackerConfig) decodeInputVariables(f *hcl.File) hcl.Diagnostics {
 	var diags hcl.Diagnostics
 
-	content, moreDiags := f.Body.Content(configSchema)
-	diags = append(diags, moreDiags...)
+	content, _ := f.Body.Content(configSchema)
 
 	// for input variables we allow to use env in the default value section.
 	ectx := &hcl.EvalContext{
@@ -188,8 +187,7 @@ func (c *PackerConfig) decodeInputVariables(f *hcl.File) hcl.Diagnostics {
 func parseLocalVariableBlocks(f *hcl.File) ([]*LocalBlock, hcl.Diagnostics) {
 	var diags hcl.Diagnostics
 
-	content, moreDiags := f.Body.Content(configSchema)
-	diags = append(diags, moreDiags...)
+	content, _ := f.Body.Content(configSchema)
 
 	var locals []*LocalBlock
 
@@ -207,8 +205,8 @@ func parseLocalVariableBlocks(f *hcl.File) ([]*LocalBlock, hcl.Diagnostics) {
 			diags = append(diags, moreDiags...)
 			for name, attr := range attrs {
 				locals = append(locals, &LocalBlock{
-					Name: name,
-					Expr: attr.Expr,
+					LocalName: name,
+					Expr:      attr.Expr,
 				})
 			}
 		}
@@ -219,7 +217,7 @@ func parseLocalVariableBlocks(f *hcl.File) ([]*LocalBlock, hcl.Diagnostics) {
 
 func (c *PackerConfig) localByName(local string) (*LocalBlock, error) {
 	for _, loc := range c.LocalBlocks {
-		if loc.Name != local {
+		if loc.LocalName != local {
 			continue
 		}
 
@@ -245,25 +243,27 @@ func (c *PackerConfig) evaluateLocalVariables(locals []*LocalBlock) hcl.Diagnost
 		// attributes, as HCL2 expressions are not allowed in a block's labels.
 		vars := FilterTraversalsByType(local.Expr.Variables(), "local")
 
-		var localDeps []*LocalBlock
+		var localDeps []refString
 		for _, v := range vars {
 			// Some local variables may be locally aliased as
 			// `local`, which
 			if len(v) < 2 {
 				continue
 			}
-			varName := v[1].(hcl.TraverseAttr).Name
-			block, err := c.localByName(varName)
+
+			depRef, err := NewRefStringFromDep(v)
 			if err != nil {
 				diags = diags.Append(&hcl.Diagnostic{
 					Severity: hcl.DiagError,
-					Summary:  "Missing variable dependency",
-					Detail: fmt.Sprintf("The expression for variable %q depends on local.%s, which is not defined.",
-						local.Name, varName),
+					Summary:  "failed to extract dependency name from traversal ref",
+					Detail: fmt.Sprintf("while preparing for evaluation of local variable %q, "+
+						"a dependency was unable to be converted to a refString. "+
+						"This is likely a Packer bug, please consider reporting it.", local.Name()),
 				})
 				continue
 			}
-			localDeps = append(localDeps, block)
+
+			localDeps = append(localDeps, depRef)
 		}
 		local.dependencies = localDeps
 	}
@@ -274,7 +274,7 @@ func (c *PackerConfig) evaluateLocalVariables(locals []*LocalBlock) hcl.Diagnost
 	}
 
 	for _, local := range c.LocalBlocks {
-		diags = diags.Extend(c.evaluateLocalVariable(local, 0))
+		diags = diags.Extend(c.recursivelyEvaluateLocalVariable(local, 0))
 	}
 
 	return diags
@@ -288,25 +288,25 @@ func (c *PackerConfig) checkForDuplicateLocalDefinition() hcl.Diagnostics {
 	localNames := map[string]*LocalBlock{}
 
 	for _, block := range c.LocalBlocks {
-		loc, ok := localNames[block.Name]
+		loc, ok := localNames[block.LocalName]
 		if ok {
 			diags = diags.Append(&hcl.Diagnostic{
 				Severity: hcl.DiagError,
 				Summary:  "Duplicate local definition",
 				Detail: fmt.Sprintf("Local variable %q is defined twice in your templates. Other definition found at %q",
-					block.Name, loc.Expr.Range()),
+					block.LocalName, loc.Expr.Range()),
 				Subject: block.Expr.Range().Ptr(),
 			})
 			continue
 		}
 
-		localNames[block.Name] = block
+		localNames[block.LocalName] = block
 	}
 
 	return diags
 }
 
-func (c *PackerConfig) evaluateLocalVariable(local *LocalBlock, depth int) hcl.Diagnostics {
+func (c *PackerConfig) recursivelyEvaluateLocalVariable(local *LocalBlock, depth int) hcl.Diagnostics {
 	// If the variable already was evaluated, we can return immediately
 	if local.evaluated {
 		return nil
@@ -325,20 +325,41 @@ func (c *PackerConfig) evaluateLocalVariable(local *LocalBlock, depth int) hcl.D
 	var diags hcl.Diagnostics
 
 	for _, dep := range local.dependencies {
-		localDiags := c.evaluateLocalVariable(dep, depth+1)
+		locBlock, err := c.getComponentByRef(dep)
+		if err != nil {
+			return diags.Append(&hcl.Diagnostic{
+				Severity: hcl.DiagError,
+				Summary:  "failed to get local variable",
+				Detail: fmt.Sprintf("While evaluating %q, its dependency %q was not found, is it defined?",
+					local.Name(), dep.String()),
+			})
+		}
+
+		localDiags := c.recursivelyEvaluateLocalVariable(locBlock.(*LocalBlock), depth+1)
 		diags = diags.Extend(localDiags)
 	}
 
-	value, moreDiags := local.Expr.Value(c.EvalContext(LocalContext, nil))
+	val, locDiags := c.evaluateLocalVariable(local)
+	if !locDiags.HasErrors() {
+		c.LocalVariables[local.LocalName] = val
+	}
+
+	return diags.Extend(locDiags)
+}
+
+func (cfg *PackerConfig) evaluateLocalVariable(local *LocalBlock) (*Variable, hcl.Diagnostics) {
+	var diags hcl.Diagnostics
+
+	value, moreDiags := local.Expr.Value(cfg.EvalContext(LocalContext, nil))
 
 	local.evaluated = true
 
 	diags = append(diags, moreDiags...)
 	if moreDiags.HasErrors() {
-		return diags
+		return nil, diags
 	}
-	c.LocalVariables[local.Name] = &Variable{
-		Name:      local.Name,
+	return &Variable{
+		Name:      local.LocalName,
 		Sensitive: local.Sensitive,
 		Values: []VariableAssignment{{
 			Value: value,
@@ -346,9 +367,7 @@ func (c *PackerConfig) evaluateLocalVariable(local *LocalBlock, depth int) hcl.D
 			From:  "default",
 		}},
 		Type: value.Type(),
-	}
-
-	return diags
+	}, diags
 }
 
 func (cfg *PackerConfig) evaluateDatasources(skipExecution bool) hcl.Diagnostics {
@@ -467,6 +486,44 @@ func (cfg *PackerConfig) recursivelyEvaluateDatasources(ref DatasourceRef, depen
 	return dependencies, diags
 }
 
+func (cfg *PackerConfig) evaluateDatasource(ds DatasourceBlock, skipExecution bool) hcl.Diagnostics {
+	var diags hcl.Diagnostics
+
+	// If we've gotten here, then it means ref doesn't seem to have any further
+	// dependencies we need to evaluate first. Evaluate it, with the cfg's full
+	// data source context.
+	datasource, startDiags := cfg.startDatasource(ds)
+	if startDiags.HasErrors() {
+		diags = append(diags, startDiags...)
+		return diags
+	}
+
+	if skipExecution {
+		placeholderValue := cty.UnknownVal(hcldec.ImpliedType(datasource.OutputSpec()))
+		ds.value = placeholderValue
+		cfg.Datasources[ds.Ref()] = ds
+		return diags
+	}
+
+	opts, _ := decodeHCL2Spec(ds.block.Body, cfg.EvalContext(DatasourceContext, nil), datasource)
+	sp := packer.CheckpointReporter.AddSpan(ds.Ref().Type, "datasource", opts)
+	realValue, err := datasource.Execute()
+	sp.End(err)
+	if err != nil {
+		diags = append(diags, &hcl.Diagnostic{
+			Summary:  err.Error(),
+			Subject:  &cfg.Datasources[ds.Ref()].block.DefRange,
+			Severity: hcl.DiagError,
+		})
+		return diags
+	}
+
+	ds.value = realValue
+	cfg.Datasources[ds.Ref()] = ds
+
+	return diags
+}
+
 // getCoreBuildProvisioners takes a list of provisioner block, starts according
 // provisioners and sends parsed HCL2 over to it.
 func (cfg *PackerConfig) getCoreBuildProvisioners(source SourceUseBlock, blocks []*ProvisionerBlock, ectx *hcl.EvalContext) ([]packer.CoreBuildProvisioner, hcl.Diagnostics) {
@@ -516,6 +573,12 @@ func (cfg *PackerConfig) getCoreBuildProvisioner(source SourceUseBlock, pb *Prov
 		}
 	}
 
+	if pb.PType == "hcp-sbom" {
+		provisioner = &packer.SBOMInternalProvisioner{
+			Provisioner: provisioner,
+		}
+	}
+
 	return packer.CoreBuildProvisioner{
 		PType:       pb.PType,
 		PName:       pb.PName,
