@@ -296,6 +296,13 @@ func (c *Core) generateCoreBuildProvisioner(rawP *template.Provisioner, rawName
 			Provisioner: provisioner,
 		}
 	}
+
+	if rawP.Type == "hcp-sbom" {
+		provisioner = &SBOMInternalProvisioner{
+			Provisioner: provisioner,
+		}
+	}
+
 	cbp = CoreBuildProvisioner{
 		PType:       rawP.Type,
 		Provisioner: provisioner,
@@ -873,7 +880,7 @@ func (c *Core) renderVarsRecursively() (*interpolate.Context, error) {
 		Key   string
 		Value string
 	}
-	sortedMap := make([]keyValue, len(repeatMap))
+	sortedMap := make([]keyValue, 0, len(repeatMap))
 	for _, k := range allKeys {
 		sortedMap = append(sortedMap, keyValue{k, repeatMap[k]})
 	}
